==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/BubbleSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BubbleSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BubbleSeriesDescription, _super);
    function BubbleSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.fj = null;
        _this.e1 = null;
        _this.fg = null;
        _this.ff = null;
        _this.ez = null;
        _this.e3 = false;
        _this.e4 = false;
        _this.fa = 0;
        _this.e9 = 0;
        _this.e5 = false;
        _this.fh = null;
        _this.fd = null;
        _this.fi = null;
        _this.fe = null;
        return _this;
    }
    BubbleSeriesDescription.prototype.get_type = function () {
        return "BubbleSeries";
    };
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberPath", {
        get: function () {
            return this.fj;
        },
        set: function (a) {
            this.fj = a;
            this.e("RadiusMemberPath");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusScale", {
        get: function () {
            return this.e1;
        },
        set: function (a) {
            this.e1 = a;
            this.e("RadiusScale");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "labelMemberPath", {
        get: function () {
            return this.fg;
        },
        set: function (a) {
            this.fg = a;
            this.e("LabelMemberPath");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberPath", {
        get: function () {
            return this.ff;
        },
        set: function (a) {
            this.ff = a;
            this.e("FillMemberPath");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillScale", {
        get: function () {
            return this.ez;
        },
        set: function (a) {
            this.ez = a;
            this.e("FillScale");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillScaleUseGlobalValues", {
        get: function () {
            return this.e3;
        },
        set: function (a) {
            this.e3 = a;
            this.e("FillScaleUseGlobalValues");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerOutlineUsesFillScale", {
        get: function () {
            return this.e4;
        },
        set: function (a) {
            this.e4 = a;
            this.e("MarkerOutlineUsesFillScale");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerOutlineBrightness", {
        get: function () {
            return this.fa;
        },
        set: function (a) {
            this.fa = a;
            this.e("MarkerOutlineBrightness");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerBrushBrightness", {
        get: function () {
            return this.e9;
        },
        set: function (a) {
            this.e9 = a;
            this.e("MarkerBrushBrightness");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusScaleUseGlobalValues", {
        get: function () {
            return this.e5;
        },
        set: function (a) {
            this.e5 = a;
            this.e("RadiusScaleUseGlobalValues");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberAsLegendLabel", {
        get: function () {
            return this.fh;
        },
        set: function (a) {
            this.fh = a;
            this.e("RadiusMemberAsLegendLabel");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberAsLegendLabel", {
        get: function () {
            return this.fd;
        },
        set: function (a) {
            this.fd = a;
            this.e("FillMemberAsLegendLabel");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberAsLegendUnit", {
        get: function () {
            return this.fi;
        },
        set: function (a) {
            this.fi = a;
            this.e("RadiusMemberAsLegendUnit");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberAsLegendUnit", {
        get: function () {
            return this.fe;
        },
        set: function (a) {
            this.fe = a;
            this.e("FillMemberAsLegendUnit");
        },
        enumerable: true,
        configurable: true
    });
    BubbleSeriesDescription.$t = markType(BubbleSeriesDescription, 'BubbleSeriesDescription', ScatterBaseDescription.$);
    return BubbleSeriesDescription;
}(ScatterBaseDescription));
export { BubbleSeriesDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/BubbleSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BubbleSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BubbleSeriesDescription, _super);
    function BubbleSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.hr = null;
        _this.g9 = null;
        _this.ho = null;
        _this.hn = null;
        _this.g7 = null;
        _this.hb = false;
        _this.hc = false;
        _this.hi = 0;
        _this.hh = 0;
        _this.hd = false;
        _this.hp = null;
        _this.hl = null;
        _this.hq = null;
        _this.hm = null;
        return _this;
    }
    BubbleSeriesDescription.prototype.get_type = function () {
        return "BubbleSeries";
    };
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberPath", {
        get: function () {
            return this.hr;
        },
        set: function (a) {
            this.hr = a;
            this.g("RadiusMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusScale", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.g("RadiusScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "labelMemberPath", {
        get: function () {
            return this.ho;
        },
        set: function (a) {
            this.ho = a;
            this.g("LabelMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberPath", {
        get: function () {
            return this.hn;
        },
        set: function (a) {
            this.hn = a;
            this.g("FillMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillScale", {
        get: function () {
            return this.g7;
        },
        set: function (a) {
            this.g7 = a;
            this.g("FillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillScaleUseGlobalValues", {
        get: function () {
            return this.hb;
        },
        set: function (a) {
            this.hb = a;
            this.g("FillScaleUseGlobalValues");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerOutlineUsesFillScale", {
        get: function () {
            return this.hc;
        },
        set: function (a) {
            this.hc = a;
            this.g("MarkerOutlineUsesFillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerOutlineBrightness", {
        get: function () {
            return this.hi;
        },
        set: function (a) {
            this.hi = a;
            this.g("MarkerOutlineBrightness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "markerBrushBrightness", {
        get: function () {
            return this.hh;
        },
        set: function (a) {
            this.hh = a;
            this.g("MarkerBrushBrightness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusScaleUseGlobalValues", {
        get: function () {
            return this.hd;
        },
        set: function (a) {
            this.hd = a;
            this.g("RadiusScaleUseGlobalValues");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberAsLegendLabel", {
        get: function () {
            return this.hp;
        },
        set: function (a) {
            this.hp = a;
            this.g("RadiusMemberAsLegendLabel");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberAsLegendLabel", {
        get: function () {
            return this.hl;
        },
        set: function (a) {
            this.hl = a;
            this.g("FillMemberAsLegendLabel");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "radiusMemberAsLegendUnit", {
        get: function () {
            return this.hq;
        },
        set: function (a) {
            this.hq = a;
            this.g("RadiusMemberAsLegendUnit");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BubbleSeriesDescription.prototype, "fillMemberAsLegendUnit", {
        get: function () {
            return this.hm;
        },
        set: function (a) {
            this.hm = a;
            this.g("FillMemberAsLegendUnit");
        },
        enumerable: false,
        configurable: true
    });
    BubbleSeriesDescription.$t = markType(BubbleSeriesDescription, 'BubbleSeriesDescription', ScatterBaseDescription.$);
    return BubbleSeriesDescription;
}(ScatterBaseDescription));
export { BubbleSeriesDescription };
